@@ -7,6 +7,7 @@ def render_chart(context,values):
     chart = {
         "chart": values,
         "type_chart": context["type"],
-        "legend_text": context["legend"]
-    }
+        "legend_text": context.get("legend") if context.get("legend") else ""
+    }        
+        
     return chart
\ No newline at end of file
